@@ -6,8 +6,11 @@ taskmaster.cli.master
 :license: Apache License 2.0, see LICENSE for more details.
 """
 
+from taskmaster.constants import DEFAULT_LOG_LEVEL, DEFAULT_ADDRESS, \
+  DEFAULT_BUFFER_SIZE
 
-def run(target, reset=False, size=10000, address='tcp://0.0.0.0:3050', log_level='INFO'):
+
+def run(target, reset=False, size=DEFAULT_BUFFER_SIZE, address=DEFAULT_ADDRESS, log_level=DEFAULT_LOG_LEVEL):
     from taskmaster.server import Server, Controller
 
     server = Server(address, size=size, log_level=log_level)
@@ -22,10 +25,10 @@ def main():
     import optparse
     import sys
     parser = optparse.OptionParser()
-    parser.add_option("--address", dest="address", default='tcp://127.0.0.1:3050')
-    parser.add_option("--size", dest="size", default='10000', type=int)
+    parser.add_option("--address", dest="address", default=DEFAULT_ADDRESS)
+    parser.add_option("--size", dest="size", default=DEFAULT_BUFFER_SIZE, type=int)
     parser.add_option("--reset", dest="reset", default=False, action='store_true')
-    parser.add_option("--log-level", dest="log_level", default='INFO')
+    parser.add_option("--log-level", dest="log_level", default=DEFAULT_LOG_LEVEL)
     (options, args) = parser.parse_args()
     if len(args) != 1:
         print 'Usage: tm-master <callback>'
